<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Circle2P</name>
    <message>
        <location filename="../Circle2P.js" line="+58"/>
        <source>First point</source>
        <translation>第一点</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point</source>
        <translation>第二点</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>The two points are identical</source>
        <translation>两点为同一点</translation>
    </message>
    <message>
        <location filename="../Circle2PInit.js" line="+2"/>
        <source>&amp;2 Points</source>
        <translation>两点(&amp;2)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle from 2 diametrically opposite points</source>
        <translation>以直径上的2点画圆</translation>
    </message>
</context>
</TS>
